SklearnMetricResults
====================

.. currentmodule:: pykeen.evaluation

.. autoclass:: SklearnMetricResults
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~SklearnMetricResults.from_dict
      ~SklearnMetricResults.from_json
      ~SklearnMetricResults.from_scores
      ~SklearnMetricResults.get_metric
      ~SklearnMetricResults.schema
      ~SklearnMetricResults.to_dict
      ~SklearnMetricResults.to_json

   .. rubric:: Methods Documentation

   .. automethod:: from_dict
   .. automethod:: from_json
   .. automethod:: from_scores
   .. automethod:: get_metric
   .. automethod:: schema
   .. automethod:: to_dict
   .. automethod:: to_json
